<?php
/*
Plugin Name: WP Fill Focus Keyword
Description: Плагин автоматически присваивает фокусное солов = тайтлу записи / страницы.
Version: 1.0
Author: Alexandr Sazonov
*/

// Register admin menu item
add_action('admin_menu', 'wp_fill_focus_keyword_menu');

function wp_fill_focus_keyword_menu() {
  add_options_page(
    'WP Fill Focus Keyword',
    'WP Fill Focus Keyword',
    'manage_options',
    'wp-fill-focus-keyword',
    'wp_fill_focus_keyword_page'
  );
}

// Create settings page
function wp_fill_focus_keyword_page() {
  ?>
  <div class="wrap">
    <h2>Fill Focus Keyword</h2>
    <p>Click the button below to fill the focus keyword for all posts and pages with the value of the post or page title.</p>
    <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>">
      <?php wp_nonce_field('wp_fill_focus_keyword'); ?>
      <input type="hidden" name="action" value="wp_fill_focus_keyword">
      <input type="submit" class="button button-primary" value="Fill All">
    </form>
  </div>
  <?php
}

// Handle form submission
add_action('admin_post_wp_fill_focus_keyword', 'wp_fill_focus_keyword_action');

function wp_fill_focus_keyword_action() {
  // Verify nonce
  check_admin_referer('wp_fill_focus_keyword');

  // Get all posts and pages
  $posts = get_posts(array(
    'post_type' => array('post', 'page'),
    'numberposts' => -1,
  ));

  // Update focus keyword for each post/page
  foreach ($posts as $post) {
    $title = get_the_title($post->ID);
    update_post_meta($post->ID, '_yoast_wpseo_focuskw', $title);
  }

  // Redirect back to settings page
  wp_redirect(add_query_arg('updated', 'true', admin_url('options-general.php?page=wp-fill-focus-keyword')));
  exit;
}